@@ -127,7 +127,8 @@ class Command(BaseCommand):
                     enddate=addr_obj.enddate,
                 )
         except Exception as err:
-            logger.info(f'В ходе выполнения команды возникла ошибка: {err}')
+            logger.info(f'В ходе выполнения команды для объекта {obj.objectid_id} возникла ошибка: {err}')
+            raise
         else:
             if addr_obj:
                 type_name = addr_obj.type_full_name
