@@ -7,8 +7,8 @@ from m3_gar.models.reestr import (
     ReestrObjects,
 )
 from m3_gar.models.util import (
-    ParamsMixin,
     RegionCodeModelMixin,
+    add_params,
     make_fk,
 )
 
@@ -25,7 +25,7 @@ class ApartmentTypes(BaseApartmentTypes):
         verbose_name_plural = 'Типы помещений'
 
 
-class Apartments(BaseApartments, ParamsMixin, RegionCodeModelMixin):
+class Apartments(BaseApartments, RegionCodeModelMixin):
     """
     Сведения по помещениям
     """
@@ -40,3 +40,5 @@ class Apartments(BaseApartments, ParamsMixin, RegionCodeModelMixin):
 make_fk(Apartments, 'aparttype', to=ApartmentTypes, null=True, blank=True)
 make_fk(Apartments, 'opertypeid', to=OperationTypes)
 make_fk(Apartments, 'objectid', to=ReestrObjects)
+
+add_params(Apartments, 'm3_gar.ApartmentsParams')
