@@ -6,8 +6,8 @@ from m3_gar.models.reestr import (
     ReestrObjects,
 )
 from m3_gar.models.util import (
-    ParamsMixin,
     RegionCodeModelMixin,
+    add_params,
     make_fk,
 )
 
@@ -15,7 +15,7 @@ from m3_gar.models.util import (
 __all__ = ['Carplaces']
 
 
-class Carplaces(BaseCarplaces, ParamsMixin, RegionCodeModelMixin):
+class Carplaces(BaseCarplaces, RegionCodeModelMixin):
     """
     Сведения по машино-местам
     """
@@ -29,3 +29,5 @@ class Carplaces(BaseCarplaces, ParamsMixin, RegionCodeModelMixin):
 
 make_fk(Carplaces, 'opertypeid', to=OperationTypes)
 make_fk(Carplaces, 'objectid', to=ReestrObjects)
+
+add_params(Carplaces, 'm3_gar.CarplacesParams')
