@@ -1,20 +1,11 @@
 import re
-from importlib import (
-    import_module,
-)
 from os import (
     listdir,
 )
 
-from django.apps import (
-    apps,
-)
 from django.conf import (
     settings,
 )
-from django.core.exceptions import (
-    ImproperlyConfigured,
-)
 from django.db.backends.base.base import (
     BaseDatabaseWrapper,
 )
@@ -25,10 +16,6 @@ from lxml import (
     etree,
 )
 
-from m3_gar.exceptions import (
-    PublisherError,
-)
-
 
 def get_by_xpath(element, xpath):
     """
@@ -187,7 +174,9 @@ class XSDFolder:
         self.files = {}
 
         files = [
-            f for f in listdir(folder_path) if (folder_path / f).is_file()
+            f for f
+            in listdir(folder_path)
+            if (folder_path / f).is_file() and f.endswith('.xsd')
         ]
 
         for file_ in files:
